@@ -115,10 +115,8 @@ static void tcc_add_systemdir(TCCState *s)
 #endif
 
 #if !defined(CONFIG_TCC_STATIC) || (defined(CONFIG_TCC_STATIC) && defined(CONFIG_TCC_STATIC_NODLOPEN))
-static void dlclose(void *p)
-{
-    FreeLibrary((HMODULE)p);
-}
+#undef dlclose
+#define dlclose(p) FreeLibrary((HMODULE)p)
 #endif
 
 #ifdef LIBTCC_AS_DLL
